@@ -27,13 +27,6 @@ class Person:
     def __str__(self):
         return f"{self.phone_number} {self.user_address} {self.send_amount}"
 
-    def has_corrent_amount(self):
-        self.current_balance = self.get_balance(self.contract_address)
-        #  -1 from expected amount to account for demurrage
-        current_balance = int(current_balance)
-        check_amount = (self.send_amount - 1)
-        return current_balance >= check_amount
-
     def get_address(self, failHard=False):
         result = subprocess.run(
             ['clicada', 'u', self.phone_number], capture_output=True, text=True)
@@ -86,27 +79,20 @@ class Person:
         else:
             return None
 
-    def send(self, contract_address, signer_keyfile, fee_limit=800000, force=False):
+    def send(self, contract_address, signer_keyfile, fee_limit=800000):
         self.contract_address = contract_address
-        if(not force and self.has_corrent_amount()):
-            log.info(
-                f"Skipping {self.phone_number} as balance is within range")
-            log.info(
-                f"  Network: {self.current_balance}, Requested: {self.send_amount}")
-            return
-        else:
-            log.info(
-                f"  Sending {self.send_amount} to {self.phone_number} ({self.user_address})")
-            cmd = ["erc20-transfer", "-p", RPC_PROVIDER, "-i", CHAIN_SPEC, "-u", "-e", contract_address, "--fee-limit",
-                   str(fee_limit), "-y", signer_keyfile, "-a", self.user_address, str(self.send_amount), "-s"]
-            log.debug("> " + " ".join(cmd))
-            try:
-                result = subprocess.run(cmd, capture_output=True,
-                                        text=True)
-                log.info("Stdout: " + str(result.stdout))
-                log.info("Error: " + str(result.stderr))
-            except Exception as e:
-                log.error(e)
+        log.info(
+            f"  Sending {self.send_amount} to {self.phone_number} ({self.user_address})")
+        cmd = ["erc20-transfer", "-p", RPC_PROVIDER, "-i", CHAIN_SPEC, "-u", "-e", contract_address, "--fee-limit",
+               str(fee_limit), "-y", signer_keyfile, "-a", self.user_address, str(self.send_amount), "-s"]
+        log.debug("> " + " ".join(cmd))
+        try:
+            result = subprocess.run(cmd, capture_output=True,
+                                    text=True)
+            log.info("Stdout: " + str(result.stdout))
+            log.info("Error: " + str(result.stderr))
+        except Exception as e:
+            log.error(e)
 
     def to_row(self) -> List[str]:
         return [self.phone_number, self.user_address, self.contract_address, self.current_balance, str(self.send_amount), self.timestamp]
